"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readEditDirState = readEditDirState;
exports.writeEditDirState = writeEditDirState;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = __importDefault(require("util"));
const createEditDirKey = (opts) => opts.editDir;
function readEditDirState(opts) {
    const state = readStateFile(opts.modulesDir);
    if (!state)
        return undefined;
    const key = createEditDirKey(opts);
    return state[key];
}
function writeEditDirState(opts) {
    modifyStateFile(opts.modulesDir, state => {
        const key = createEditDirKey(opts);
        state[key] = {
            patchedPkg: opts.patchedPkg,
            applyToAll: opts.applyToAll,
        };
    });
}
function modifyStateFile(modulesDir, modifyState) {
    const filePath = getStateFilePath(modulesDir);
    let state = readStateFile(modulesDir);
    if (!state) {
        state = {};
        fs_1.default.mkdirSync(path_1.default.dirname(filePath), { recursive: true });
    }
    modifyState(state);
    fs_1.default.writeFileSync(filePath, JSON.stringify(state, undefined, 2));
}
function readStateFile(modulesDir) {
    let fileContent;
    try {
        fileContent = fs_1.default.readFileSync(getStateFilePath(modulesDir), 'utf-8');
    }
    catch (err) {
        if (util_1.default.types.isNativeError(err) && 'code' in err && err.code === 'ENOENT') {
            return undefined;
        }
        throw err;
    }
    return JSON.parse(fileContent);
}
function getStateFilePath(modulesDir) {
    return path_1.default.join(modulesDir, '.pnpm_patches', 'state.json');
}
//# sourceMappingURL=stateFile.js.map